==> json-schema-for-humans-0.33.1.tar.gz: json-schema-for-humans-0.33.1/docs/examples/examples_md_nested_with_badges/references_url_two_levels.md <==
# Schema Docs

- [1. [Optional] Property root > described](#described)
  - [1.1. [Optional] Property root > described > name](#described_name)
  - [1.2. [Optional] Property root > described > alignment](#described_alignment)

| Type                      | `object`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

**Description:** Testing $ref of a remote $ref

<details>
<summary><strong> <a name="described"></a>1. [Optional] Property root > described</strong>  

</summary>
<blockquote>

| Type                      | `object`                                                                                                               |
| ------------------------- | ---------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.")    |
| **Defined in**            | https://raw.githubusercontent.com/coveooss/json-schema-for-humans/master/docs/examples/cases/description_from_ref.json |
|                           |                                                                                                                        |

<details>
<summary><strong> <a name="described_name"></a>1.1. [Optional] Property root > described > name</strong>  

</summary>
<blockquote>

| Type                      | `string`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
| **Defined in**            | #/definitions/filled_string                                                                                         |
|                           |                                                                                                                     |

**Description:** a filled string

| Restrictions   |   |
| -------------- | - |
| **Min length** | 1 |
|                |   |

</blockquote>
</details>

<details>
<summary><strong> <a name="described_alignment"></a>1.2. [Optional] Property root > described > alignment</strong>  

</summary>
<blockquote>

| Type                      | `string`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
| **Same definition as**    | `[name](#described_name)`                                                                                           |
|                           |                                                                                                                     |

**Description:** a filled string

</blockquote>
</details>

</blockquote>
</details>

----------------------------------------------------------------------------------------------------------------------------
Generated using [json-schema-for-humans](https://github.com/coveooss/json-schema-for-humans) on date

==> json-schema-for-humans-0.34.4.tar.gz: json-schema-for-humans-0.34.4/docs/examples/examples_md_nested_with_badges/references_url_two_levels.md <==
# Schema Docs

- [1. [Optional] Property root > described](#described)
  - [1.1. [Optional] Property root > described > name](#described_name)
  - [1.2. [Optional] Property root > described > alignment](#described_alignment)

| Type                      | `object`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
|                           |                                                                                                                     |

**Description:** Testing $ref of a remote $ref

<details>
<summary><strong> <a name="described"></a>1. [Optional] Property root > described</strong>  

</summary>
<blockquote>

| Type                      | `object`                                                                                                               |
| ------------------------- | ---------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.")    |
| **Defined in**            | https://raw.githubusercontent.com/coveooss/json-schema-for-humans/master/docs/examples/cases/description_from_ref.json |
|                           |                                                                                                                        |

<details>
<summary><strong> <a name="described_name"></a>1.1. [Optional] Property root > described > name</strong>  

</summary>
<blockquote>

| Type                      | `string`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
| **Defined in**            | #/definitions/filled_string                                                                                         |
|                           |                                                                                                                     |

**Description:** a filled string

| Restrictions   |   |
| -------------- | - |
| **Min length** | 1 |
|                |   |

</blockquote>
</details>

<details>
<summary><strong> <a name="described_alignment"></a>1.2. [Optional] Property root > described > alignment</strong>  

</summary>
<blockquote>

| Type                      | `string`                                                                                                            |
| ------------------------- | ------------------------------------------------------------------------------------------------------------------- |
| **Additional properties** | [![badge](https://img.shields.io/badge/Any+type-allowed-green)](# "Additional Properties of any type are allowed.") |
| **Same definition as**    | [name](#described_name)                                                                                             |
|                           |                                                                                                                     |

**Description:** a filled string

</blockquote>
</details>

</blockquote>
</details>

----------------------------------------------------------------------------------------------------------------------------
Generated using [json-schema-for-humans](https://github.com/coveooss/json-schema-for-humans) on date
